@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.base;
@@ -42,6 +42,7 @@ import org.jajuk.util.Const;
 import org.jajuk.util.MD5Processor;
 import org.jajuk.util.ReadOnlyIterator;
 import org.jajuk.util.error.JajukException;
+import org.jajuk.util.error.JajukRuntimeException;
 
 /**
  * Convenient class to manage Albums.
@@ -72,9 +73,12 @@ public final class AlbumManager extends ItemManager implements Observer {
     // Expand
     registerProperty(new PropertyMetaInformation(Const.XML_EXPANDED, false, false, false, false,
         true, Boolean.class, false));
-    // Cover path
-    registerProperty(new PropertyMetaInformation(Const.XML_ALBUM_COVER, false, false, false, false,
-        false, String.class, null));
+    // Discovered Cover path
+    registerProperty(new PropertyMetaInformation(Const.XML_ALBUM_DISCOVERED_COVER, false, false,
+        false, false, false, String.class, null));
+    // Selected Cover path
+    registerProperty(new PropertyMetaInformation(Const.XML_ALBUM_SELECTED_COVER, false, false,
+        false, false, false, String.class, null));
     // Disc id
     registerProperty(new PropertyMetaInformation(Const.XML_ALBUM_DISC_ID, false, true, true, false,
         false, Long.class, -1l));
@@ -117,11 +121,10 @@ public final class AlbumManager extends ItemManager implements Observer {
 
   /**
    * Register an Album with a known id.
-   * 
-   * @param sName DOCUMENT_ME
+   *
    * @param sId DOCUMENT_ME
+   * @param sName DOCUMENT_ME
    * @param discID DOCUMENT_ME
-   * 
    * @return the album
    */
   public Album registerAlbum(String sId, String sName, long discID) {
@@ -261,7 +264,7 @@ public final class AlbumManager extends ItemManager implements Observer {
   /**
    * Get sorted list of albums associated with this item.
    * 
-   * @param item DOCUMENT_ME
+   * @param item the item
    * 
    * @return a list of item, void list if no result
    */
@@ -286,9 +289,10 @@ public final class AlbumManager extends ItemManager implements Observer {
                 albumSet.add(album);
               } else if (item instanceof Genre && track.getGenre().equals(item)) {
                 albumSet.add(album);
-              }
-              if (item instanceof Year && track.getYear().equals(item)) {
+              } else if (item instanceof Year && track.getYear().equals(item)) {
                 albumSet.add(album);
+              } else {
+                throw new JajukRuntimeException("Association not implemented " + item);
               }
             }
           }
@@ -453,8 +457,8 @@ public final class AlbumManager extends ItemManager implements Observer {
     if (sortedAlbums.size() == 0) {
       return new ArrayList<Album>();
     }
-    List<Album> sublist = sortedAlbums.subList(sortedAlbums.size() - (1 + size), sortedAlbums
-        .size() - 1);
+    List<Album> sublist = sortedAlbums.subList(sortedAlbums.size() - (1 + size),
+        sortedAlbums.size() - 1);
     // Shuffle the result
     Collections.shuffle(sublist);
     // The result is a sublist of shuffled albums, if we have less
@@ -550,10 +554,11 @@ public final class AlbumManager extends ItemManager implements Observer {
 
   /**
    * Reset cached cover url for every album.
+   * Note that we reset only cached/discovered covers, not user-selected covers.
    */
   public void resetCoverCache() {
     for (Album album : getAlbums()) {
-      album.setProperty(Const.XML_ALBUM_COVER, "");
+      album.setProperty(Const.XML_ALBUM_DISCOVERED_COVER, "");
     }
   }
 
