@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.base;
@@ -61,6 +61,7 @@ public final class FileManager extends ItemManager {
 
   /** File comparator based on rate. */
   private final Comparator<File> rateComparator = new Comparator<File>() {
+    @Override
     public int compare(File file1, File file2) {
       long lRate1 = file1.getTrack().getRate();
       long lRate2 = file2.getTrack().getRate();
@@ -180,12 +181,12 @@ public final class FileManager extends ItemManager {
     // Under windows, all files/directories with different cases should get
     // the same ID
     if (UtilSystem.isUnderWindows()) {
-      id = MD5Processor.hash(new StringBuilder(dir.getDevice().getName()).append(
-          dir.getRelativePath().toLowerCase(Locale.getDefault())).append(
-          sName.toLowerCase(Locale.getDefault())).toString());
+      id = MD5Processor.hash(new StringBuilder(dir.getDevice().getName())
+          .append(dir.getRelativePath().toLowerCase(Locale.getDefault()))
+          .append(sName.toLowerCase(Locale.getDefault())).toString());
     } else {
-      id = MD5Processor.hash(new StringBuilder(dir.getDevice().getName()).append(
-          dir.getRelativePath()).append(sName).toString());
+      id = MD5Processor.hash(new StringBuilder(dir.getDevice().getName())
+          .append(dir.getRelativePath()).append(sName).toString());
     }
     return id;
   }
@@ -247,8 +248,8 @@ public final class FileManager extends ItemManager {
       Track track = fileOld.getTrack();
       // Remove old file from associated track
       track.removeFile(fileOld);
-      org.jajuk.base.File fNew = new File(sNewId, sNewName, fileOld.getDirectory(), track, fileOld
-          .getSize(), fileOld.getQuality());
+      org.jajuk.base.File fNew = new File(sNewId, sNewName, fileOld.getDirectory(), track,
+          fileOld.getSize(), fileOld.getQuality());
       // transfer all properties and reset id and name
       // We use a shallow copy of properties to avoid any properties share between
       // two items
@@ -272,14 +273,15 @@ public final class FileManager extends ItemManager {
   }
 
   /**
-   * Change a file directory.
+   * Change a file directory and actually move the old file to the new directory.
    * 
    * @param old old file
    * @param newDir new dir
    * 
    * @return new file or null if an error occurs
+   * @throws JajukException the jajuk exception
    */
-  public File changeFileDirectory(File old, Directory newDir) {
+  public File changeFileDirectory(File old, Directory newDir) throws JajukException {
     lock.writeLock().lock();
     try {
       // recalculate file ID
@@ -294,6 +296,15 @@ public final class FileManager extends ItemManager {
       fNew.setProperty(Const.XML_ID, sNewId);
       fNew.setProperty(Const.XML_DIRECTORY, newDir.getID());
 
+      // Real IO move
+      try {
+        if (!old.getFIO().renameTo(fNew.getFIO())) {
+          throw new CannotRenameException(134);
+        }
+      } catch (Exception e) {
+        throw new CannotRenameException(134, e);
+      }
+
       // OK, remove old file and register this new file
       removeFile(old);
       registerItem(fNew);
@@ -332,7 +343,7 @@ public final class FileManager extends ItemManager {
     lock.writeLock().lock();
     try {
       // We need to remove the file from the track !
-      TrackManager.getInstance().removefile(file.getTrack(), file);
+      TrackManager.getInstance().removeFile(file);
       removeItem(file);
     } finally {
       lock.writeLock().unlock();
@@ -437,6 +448,7 @@ public final class FileManager extends ItemManager {
       }
       Collections.sort(alEligibleFiles, new Comparator<File>() {
 
+        @Override
         public int compare(File f1, File f2) {
           if (f1.getTrack().getAlbum().equals(f2.getTrack().getAlbum())) {
             int comp = (int) (f1.getTrack().getOrder() - f2.getTrack().getOrder());
@@ -491,8 +503,8 @@ public final class FileManager extends ItemManager {
     List<File> alEligibleFiles = new ArrayList<File>(1000);
     List<Track> tracks = TrackManager.getInstance().getTracks();
     // Filter by age
-    CollectionUtils.filter(tracks, new JajukPredicates.AgePredicate(Conf
-        .getInt(Const.CONF_OPTIONS_NOVELTIES_AGE)));
+    CollectionUtils.filter(tracks,
+        new JajukPredicates.AgePredicate(Conf.getInt(Const.CONF_OPTIONS_NOVELTIES_AGE)));
     // filter banned tracks
     CollectionUtils.filter(tracks, new JajukPredicates.BannedTrackPredicate());
     for (Track track : tracks) {
@@ -509,6 +521,7 @@ public final class FileManager extends ItemManager {
     }
     // sort alphabetically and by date, newest first
     Collections.sort(alEligibleFiles, new Comparator<File>() {
+      @Override
       public int compare(File file1, File file2) {
         String sCompared1 = file1.getTrack().getDiscoveryDate().getTime() + file1.getAbsolutePath();
         String sCompared2 = file2.getTrack().getDiscoveryDate().getTime() + file2.getAbsolutePath();
