@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.services.covers;
@@ -55,6 +55,9 @@ public class Cover implements Comparable<Cover>, Const {
    * LOCAL_COVER : cover located on the disk and not a standard one
    * </p>
    * <p>
+   * TAG_COVER : tag cover located inside the audio files as a tag
+   * </p>
+   * <p>
    * STANDARD COVER : cover located on the disk with a obvious name (cover.png,
    * front.png...)
    * </p>
@@ -62,7 +65,7 @@ public class Cover implements Comparable<Cover>, Const {
    * REMOTE_COVER : cover from the web (HTTP protocol)
    * </p>
    * <p>
-   * SELECTED_COVER : local cover selected by user as the default local cover to
+   * SELECTED_COVER : local or tag cover selected by user as the default local cover to
    * display in thumbs..
    * </p>
    */
@@ -70,21 +73,21 @@ public class Cover implements Comparable<Cover>, Const {
 
     /** DOCUMENT_ME. */
     NO_COVER,
-    
+
     /** DOCUMENT_ME. */
     REMOTE_COVER,
-    
+
     /** DOCUMENT_ME. */
     LOCAL_COVER,
+
+    // cover stored in the tag of a file
+    TAG_COVER,
     
     /** DOCUMENT_ME. */
     STANDARD_COVER,
     
     /** DOCUMENT_ME. */
-    SELECTED_COVER,
-    // cover stored in the tag of a file
-    /** DOCUMENT_ME. */
-    TAG_COVER
+    SELECTED_COVER
   }
 
   /** Cover URL*. */
@@ -130,7 +133,7 @@ public class Cover implements Comparable<Cover>, Const {
   }
 
   /*
-   * (non-Javadoc) The priority order is : SELECTED > STANDARD > LOCAL > REMOTE > NO_COVER
+   * (non-Javadoc) The priority order is : SELECTED > STANDARD > TAG > LOCAL > REMOTE > NO_COVER
    * 
    * @see java.lang.Comparable#compareTo(java.lang.Object)
    */
