@@ -45,13 +45,18 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
   /** Time elapsed in ms. */
   private long lTime = 0;
 
+  /** Actually played time */
+  private long actuallyPlayedTimeMillis = 0l;
+
+  private long lastPlayTimeUpdate = System.currentTimeMillis();
+
   /** Length to be played in secs. */
   private long length;
 
   /** Starting position. */
   private float fPosition;
 
-  /** Current track estimated duration in ms. */
+  /** Current track estimated total duration in ms. */
   private long lDuration;
 
   /** Volume when starting fade. */
@@ -90,16 +95,23 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
   /** [Windows only] Force use of shortnames. */
   private boolean bForcedShortnames = false;
 
+  /** English-specific end of file pattern */
+  private Pattern patternEndOfFileEnglish = Pattern
+      .compile("Exiting\\x2e\\x2e\\x2e.*\\(End of file\\)");
+
+  /** Language-agnostic end of file pattern */
+  private Pattern patternEndOfFileGeneric = Pattern.compile(".*\\x2e\\x2e\\x2e.*\\(.*\\)");
+
   /**
    * Position and elapsed time getter.
    */
   private class PositionThread extends Thread {
 
     /**
-     * Instantiates a new position thread.
-     * 
-     * @param name DOCUMENT_ME
-     */
+    * Instantiates a new position thread.
+    * 
+    * @param name DOCUMENT_ME
+    */
     public PositionThread(String name) {
       super(name);
     }
@@ -112,6 +124,7 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
     @Override
     public void run() {
       int comp = 0;
+      lastPlayTimeUpdate = System.currentTimeMillis();
       Track current = fCurrent.getTrack();
       while (!bStop && !bEOF) { // stop this thread
         try {
@@ -128,6 +141,14 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
             // Do not call a get_percent_pos if paused, it resumes the player
             // (mplayer issue)
             sendCommand("get_time_pos");
+
+            // Get track length if required. Do not launch "get_time_length" only 
+            // once because some fast computer makes mplayer start too fast and
+            // the slave mode is not yet opened so this command is not token into account.
+            // See bug #1816 (Track length is zero after a restart)
+            if (lDuration == 0) {
+              sendCommand("get_time_length");
+            }
             // Every 2 time units, increase actual play time. We wait this
             // delay for perfs and for precision
             if (comp > 0 && comp % TOTAL_PLAYTIME_UPDATE_INTERVAL == 0) {
@@ -172,8 +193,9 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
     @Override
     public void run() {
       try {
-        Pattern patternEndOfFile = Pattern.compile(".*\\x2e\\x2e\\x2e.*\\(.*\\).*");
         BufferedReader in = new BufferedReader(new InputStreamReader(proc.getInputStream()));
+        // While we don't know the mplayer language, patternEndOfFile matches any language end of file pattern : .*... (.*)
+        Pattern patternEndOfFile = patternEndOfFileGeneric;
         try {
           String line = null;
           while (!bStop) {
@@ -189,8 +211,12 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
               break;
             }
             // Very verbose :
-            // Log.debug("Output from MPlayer: " + line);
-            if (line.indexOf("ANS_TIME_POSITION") != -1) {
+            //Log.debug("Output from MPlayer: " + line);
+
+            // Detect mplayer language
+            if (line.indexOf("Starting playback") != -1) {
+              patternEndOfFile = patternEndOfFileEnglish;
+            } else if (line.indexOf("ANS_TIME_POSITION") != -1) {
               // Stream is actually opened now
               bOpening = false;
 
@@ -199,8 +225,7 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
               // We need to compute the elapsed time. The issue here is the fact
               // that mplayer sometimes returns false getPos() values (for vbr).
               // The other problem is that the user can seek forward or rewind
-              // in
-              // the track so we can't just count the system time.
+              // in the track so we can't just count the system time.
               // The solution we got is :
               // - If user never seeked into the current track, compute the
               // elapsed time upon real system date.
@@ -218,9 +243,16 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
               } else {
                 lTime = System.currentTimeMillis() - dateStart - pauseCount;
               }
+              // update actually played duration
+              if (lastPlayTimeUpdate > 0 && !bPaused) {
+                actuallyPlayedTimeMillis += (System.currentTimeMillis() - lastPlayTimeUpdate);
+              }
+              lastPlayTimeUpdate = System.currentTimeMillis();
+
               // Store current position for use at next startup
-              Conf.setProperty(Const.CONF_STARTUP_LAST_POSITION, Float
-                  .toString(getCurrentPosition()));
+              Conf.setProperty(Const.CONF_STARTUP_LAST_POSITION,
+                  Float.toString(getCurrentPosition()));
+
               // Cross-Fade test
               if (!bFading && iFadeDuration > 0
               // Length = 0 for some buggy audio headers
@@ -240,9 +272,9 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
                 // at last progress()
                 float fVolumeStep = fadingVolume
                 // we double the refresh period to make sure to
-                    // reach 0 at the end of iterations because
-                    // we don't as many mplayer response as queries,
-                    // tested on 10 & 20 sec of fading
+                // reach 0 at the end of iterations because
+                // we don't as many mplayer response as queries,
+                // tested on 10 & 20 sec of fading
                     * ((float) PROGRESS_STEP / iFadeDuration);
                 float fNewVolume = fVolume - fVolumeStep;
                 // decrease volume by n% of initial volume
@@ -382,8 +414,6 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
       if (fPosition > 0.0f) {
         seek(fPosition);
       }
-      // Get track length
-      sendCommand("get_time_length");
     } else {
       // try to kill the mplayer process if still alive
       if (proc != null) {
@@ -460,10 +490,10 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
     }
   }
 
-  /**
-   * Gets the current position.
+  /*
+   * (non-Javadoc)
    * 
-   * @return current position as a float ex: 0.2f
+   * @see org.jajuk.players.IPlayerImpl#getCurrentPosition()
    */
   @Override
   public float getCurrentPosition() {
@@ -473,16 +503,24 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
     return ((float) lTime) / lDuration;
   }
 
-  /**
-   * Gets the elapsed time.
+  /*
+   * (non-Javadoc)
    * 
-   * @return Returns the lTime in ms
+   * @see org.jajuk.players.IPlayerImpl#getElapsedTimeMillis()
    */
   @Override
-  public long getElapsedTime() {
+  public long getElapsedTimeMillis() {
     return lTime;
   }
 
+  /* (non-Javadoc)
+  * @see org.jajuk.services.players.IPlayerImpl#getActuallyPlayedTimeMillis()
+  */
+  @Override
+  public long getActuallyPlayedTimeMillis() {
+    return actuallyPlayedTimeMillis;
+  }
+
   /*
    * (non-Javadoc)
    * 
@@ -528,10 +566,10 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
   /*
    * (non-Javadoc)
    * 
-   * @see org.jajuk.players.IPlayerImpl#getCurrentLength()
+   * @see org.jajuk.players.IPlayerImpl#getDurationSec()
    */
   @Override
-  public long getCurrentLength() {
+  public long getDurationSec() {
     return lDuration;
   }
 
@@ -566,6 +604,7 @@ public class MPlayerPlayerImpl extends AbstractMPlayerImpl {
    */
   @Override
   public void resume() throws Exception {
+    lastPlayTimeUpdate = System.currentTimeMillis();
     super.resume();
     setVolume(fVolume);
   }
