@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -20,14 +20,21 @@
  */
 package org.jajuk.services.tags;
 
+import java.awt.image.BufferedImage;
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.logging.LogManager;
 
+import javax.imageio.ImageIO;
+
 import org.apache.commons.lang.StringUtils;
+import org.jajuk.services.core.SessionService;
+import org.jajuk.services.covers.Cover;
+import org.jajuk.services.covers.Cover.CoverType;
 import org.jajuk.util.Const;
+import org.jajuk.util.MD5Processor;
 import org.jajuk.util.UtilFeatures;
 import org.jajuk.util.error.JajukException;
 import org.jajuk.util.log.Log;
@@ -38,6 +45,7 @@ import org.jaudiotagger.tag.FieldKey;
 import org.jaudiotagger.tag.KeyNotFoundException;
 import org.jaudiotagger.tag.Tag;
 import org.jaudiotagger.tag.TagField;
+import org.jaudiotagger.tag.datatype.Artwork;
 import org.jaudiotagger.tag.id3.ID3v1Tag;
 import org.jaudiotagger.tag.id3.ID3v24Tag;
 
@@ -481,4 +489,50 @@ public class JAudioTaggerTagImpl implements ITagImpl, Const {
     tag.setField(FieldKey.DISC_NO, Long.toString(discnumber));
   }
 
+  /* (non-Javadoc)
+   * @see org.jajuk.services.tags.ITagImpl#getCovers()
+   */
+  @Override
+  public List<Cover> getCovers() throws Exception {
+    List<Cover> covers = new ArrayList<Cover>(1);
+    List<Artwork> artworkList = tag.getArtworkList();
+    // index : prefix for cover file extracted into the cache directory
+    int index = 1;
+    for (Artwork artwork : artworkList) {
+      File coverFile = buildTagCacheFile(index);
+      // [PERF] Only extract artworks if the cache file doesn't yet exist.
+      if (!coverFile.exists()) {
+        byte[] imageRawData = artwork != null ? artwork.getBinaryData() : null;
+        if (imageRawData != null) {
+          BufferedImage bi = ImageIO.read(new ByteArrayInputStream(imageRawData));
+          if (bi != null) {
+            ImageIO.write(bi, "png", coverFile);
+          }
+        }
+      }
+      Cover cover = new Cover(coverFile, CoverType.TAG_COVER);
+      covers.add(cover);
+      index++;
+    }
+    return covers;
+  }
+
+  /**
+   * Build target cover path. The cover tag is extracted and copied to a file in the cache
+   * it is uniquely identified by absolute filename AND file last change so we force recreating the 
+   * cache if user add/remove cover tags from audio files using another tool.
+   * To avoid overriding of tags between files, each potentially containing several artworks.
+   * @param index index of the tag
+   * @return file for upcoming cache
+   */
+  private File buildTagCacheFile(int index) {
+    File fio = audioFile.getFile();
+    String absolutePath = fio.getAbsolutePath();
+    long lastChange = fio.lastModified();
+    String hash = MD5Processor.hash(absolutePath + lastChange);
+    File coverFile = SessionService.getConfFileByPath(Const.FILE_CACHE + '/' + hash + "_" + index
+        + "_" + Const.TAG_COVER_FILE);
+    return coverFile;
+  }
+
 }
