@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -75,6 +75,7 @@ public class PasteAction extends JajukAction {
   @Override
   @SuppressWarnings("unchecked")
   public void perform(ActionEvent e) {
+    //TODO : rework this method into smaller units
     JComponent source = (JComponent) e.getSource();
     final List<Item> alSelected = (List<Item>) source.getClientProperty(Const.DETAIL_SELECTION);
     final List<Item> itemsToMove = ItemMoveManager.getInstance().getAll();
@@ -190,13 +191,6 @@ public class PasteAction extends JajukAction {
             }
             try {
               showMessage(f.getFIO());
-              final java.io.File fileNew = new java.io.File(
-                  new StringBuilder(dir.getAbsolutePath()).append("/").append(f.getName())
-                      .toString());
-              if (!f.getFIO().renameTo(fileNew)) {
-                throw new Exception("Cannot move item: " + f.getAbsolutePath() + " to "
-                    + fileNew.getAbsolutePath());
-              }
               FileManager.getInstance().changeFileDirectory(f, destDir);
             } catch (Exception ioe) {
               Log.error(131, ioe);
@@ -229,7 +223,7 @@ public class PasteAction extends JajukAction {
                 throw new Exception("Cannot move item: " + pl.getFIO().getAbsolutePath() + " to "
                     + fileNew.getAbsolutePath());
               }
-
+              
               // Refresh source and destination
               destDir.refresh(false);
               // Refresh source directories as well
@@ -242,27 +236,28 @@ public class PasteAction extends JajukAction {
               Messages.showErrorMessage(131);
               bErrorOccured = true;
             }
-
           }
+          
+        
           for (Directory d : alDirs) {
             try {
               java.io.File src = new java.io.File(d.getAbsolutePath());
               java.io.File dst = new java.io.File(dir.getAbsolutePath() + "/" + d.getName());
               showMessage(src);
-              java.io.File newDir = new java.io.File(new StringBuilder(dst.getAbsolutePath())
-                  .toString());
+              java.io.File newDir = new java.io.File(
+                  new StringBuilder(dst.getAbsolutePath()).toString());
               if (!src.renameTo(newDir)) {
                 throw new Exception("Cannot move item: " + src.getAbsolutePath() + " to "
                     + dst.getAbsolutePath());
               }
               DirectoryManager.getInstance().removeDirectory(d.getID());
-              destDir.refresh(false);
             } catch (Exception ioe) {
               Log.error(131, ioe);
               Messages.showErrorMessage(131);
               bErrorOccured = true;
             }
           }
+         
           try {
             destDir.refresh(false);
             // Refresh source directories as well
@@ -273,6 +268,7 @@ public class PasteAction extends JajukAction {
             Log.error(e1);
             bErrorOccured = true;
           }
+    
         } else if (moveAction == ItemMoveManager.MoveActions.COPY) {
           for (File f : alFiles) {
             if (!overwriteAll) {
@@ -349,13 +345,14 @@ public class PasteAction extends JajukAction {
             bErrorOccured = true;
           }
         }
+     
         ObservationManager.notify(new JajukEvent(JajukEvents.DEVICE_REFRESH));
         UtilGUI.stopWaiting();
         if (!bErrorOccured) {
           InformationJPanel.getInstance().setMessage(Messages.getString("Success"),
               InformationJPanel.MessageType.INFORMATIVE);
         }
-
+      
       }
     }.start();
   }
