@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.ui.actions;
@@ -143,7 +143,7 @@ public class RefactorAction {
       // Move file and related cover but save old Directory pathname
       // for future deletion
       try {
-        final java.io.File fCover = tCurrent.getAlbum().findCoverFile();
+        final java.io.File fCover = tCurrent.getAlbum().findCover();
         if (fCover != null) {
           java.io.File destFile = new java.io.File(fNew.getParent() + RefactorAction.sFS
               + fCover.getName());
