@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.ui.views;
@@ -154,6 +154,9 @@ public abstract class AbstractTreeView extends ViewAdapter {
 
   /** Used to differentiate tree/table sync due to internal events from users's ones. */
   boolean bInternalAction = false;
+  
+  /** Flag used to set tree is refreshing */
+  boolean refreshing = false;
 
   /*
    * (non-Javadoc)
