@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -133,6 +133,7 @@ public class QueueView extends PlaylistView {
     jtbAutoScroll.setToolTipText(Messages.getString("QueueView.2"));
     jtbAutoScroll.setSelected(Conf.getBoolean(Const.CONF_AUTO_SCROLL));
     jtbAutoScroll.addActionListener(new ActionListener() {
+      @Override
       public void actionPerformed(ActionEvent e) {
         Conf.setProperty(Const.CONF_AUTO_SCROLL, Boolean.toString(jtbAutoScroll.isSelected()));
         if (jtbAutoScroll.isSelected()) {
@@ -153,7 +154,7 @@ public class QueueView extends PlaylistView {
     // Add items
     jpEditorControl.setLayout(new MigLayout("insets 5", "[][grow][]"));
     jpEditorControl.add(jtb, "left,gapright 15::");
-    jpEditorControl.add(jlTitle, "right,gapright 5");
+    jpEditorControl.add(jlTitle, "center,gapright 5,grow");
     jpEditorControl.add(jtbAutoScroll, "right");
     editorModel = new PlaylistTableModel(true);
     editorTable = new JajukTable(editorModel, CONF_QUEUE_COLUMNS);
@@ -180,6 +181,7 @@ public class QueueView extends PlaylistView {
     // behavior here in the queue view : it must go to selection without keeping
     // previous FIFO
     jmiFilePlay.addActionListener(new ActionListener() {
+      @Override
       public void actionPerformed(ActionEvent e) {
         goToSelection();
       }
@@ -214,6 +216,7 @@ public class QueueView extends PlaylistView {
     });
     // Add specific behavior on left click
     editorTable.setCommand(new ILaunchCommand() {
+      @Override
       public void launch(int nbClicks) {
         int iSelectedCol = editorTable.getSelectedColumn();
         // Convert column selection as columns may have been moved
@@ -305,6 +308,7 @@ public class QueueView extends PlaylistView {
   @Override
   public void update(final JajukEvent event) {
     SwingUtilities.invokeLater(new Runnable() {
+      @Override
       public void run() {
         try {
           JajukEvents subject = event.getSubject();
@@ -388,6 +392,7 @@ public class QueueView extends PlaylistView {
   private void autoScroll() {
 
     SwingUtilities.invokeLater(new Runnable() {
+      @Override
       public void run() {
 
         if (QueueModel.getQueueSize() > 0) {
