@@ -987,6 +987,9 @@ public interface Const {
 
   /** Remembered directory for parties. */
   String CONF_PREPARE_PARTY = "jajuk.prepare_party.";
+  
+  /** Refreshing delay. */
+  String CONF_REFRESHING_DELAY_MS = "jajuk.refreshing_delay_ms";
 
   /** Shuffle/novelties mode. */
   String MODE_ALBUM = "album";
