@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.util;
@@ -33,13 +33,14 @@ import java.util.StringTokenizer;
 import javax.swing.JOptionPane;
 
 import org.apache.commons.io.FileUtils;
+import org.jajuk.base.Album;
 import org.jajuk.base.AlbumManager;
 import org.jajuk.base.Collection;
 import org.jajuk.base.Device;
 import org.jajuk.base.DeviceManager;
+import org.jajuk.base.SearchResult.SearchResultType;
 import org.jajuk.base.Track;
 import org.jajuk.base.TrackManager;
-import org.jajuk.base.SearchResult.SearchResultType;
 import org.jajuk.services.core.SessionService;
 import org.jajuk.services.dj.AmbienceManager;
 import org.jajuk.ui.thumbnails.ThumbnailManager;
@@ -50,7 +51,7 @@ import org.jajuk.util.log.Log;
  * 
  * Jajuk version sheme is XX.YY.ZZ (two digits possible for each part of the release)
  */
-public final class UpgradeManager {
+public final class UpgradeManager implements Const {
 
   /** Last jajuk release known from Internet (parsed from a pad file). */
   private static String newVersionName;
@@ -250,6 +251,18 @@ public final class UpgradeManager {
     }
   }
 
+  /**
+   * For Jajuk < 1.9.3: 'cover' tag can't contain "none" string
+   */
+  private static void upgradeNoneCover() {
+    for (Album album : AlbumManager.getInstance().getAlbums()) {
+      if (COVER_NONE.equals(album.getStringValue(XML_ALBUM_SELECTED_COVER))) {
+        album.setProperty(XML_ALBUM_SELECTED_COVER, "");
+      }
+    }
+
+  }
+
   /**
    * For Jajuk < 1.9: bootstrap file is now in XML format
    * <br>
@@ -283,8 +296,8 @@ public final class UpgradeManager {
         Properties prop = null;
         // Try to load a bootstrap file using plain text old format
         prop = new Properties();
-        FileInputStream fis = new FileInputStream(SessionService
-            .getBootstrapPath(Const.FILE_BOOTSTRAP_OLD));
+        FileInputStream fis = new FileInputStream(
+            SessionService.getBootstrapPath(Const.FILE_BOOTSTRAP_OLD));
         prop.load(fis);
         fis.close();
 
@@ -547,6 +560,8 @@ public final class UpgradeManager {
         upgradeCollectionRating();
         // For Jajuk < 1.9
         upgradeNoMoreAlbumArtistsForAlbums();
+        // For Jajuk < 1.9.3
+        upgradeNoneCover();
       }
       // Major releases upgrade specific operations
       if (isMajorMigration()) {
