@@ -648,7 +648,7 @@ public class JUnitHelpers {
     }
 
     @Override
-    public long getElapsedTime() {
+    public long getElapsedTimeMillis() {
 
       return 0;
     }
@@ -666,10 +666,19 @@ public class JUnitHelpers {
     }
 
     @Override
-    public long getCurrentLength() {
+    public long getDurationSec() {
 
       return 0;
     }
+
+    /* (non-Javadoc)
+     * @see org.jajuk.services.players.IPlayerImpl#getActuallyPlayedTimeMillis()
+     */
+    @Override
+    public long getActuallyPlayedTimeMillis() {
+      // TODO Auto-generated method stub
+      return 0;
+    }
   }
 
   public static Track getTrack(int i) {
